aztec-nr - protocol_types::abis::tube

Struct PublicTubeData

pub struct PublicTubeData {
    pub public_inputs: PrivateToPublicKernelCircuitPublicInputs,
    pub proof: TubeProof,
    pub vk_data: VkData<115>,
}

Fields

public_inputs: PrivateToPublicKernelCircuitPublicInputs
proof: TubeProof
vk_data: VkData<115>

Implementations

impl PublicTubeData

pub fn validate_vk_in_vk_tree(self)

Validates that the vk hash exists in the vk tree at the expected index.

Trait implementations

impl Verifiable for PublicTubeData

pub fn verify(self)

Verifies the proof against the verification key and public inputs. The vk hash is also checked in the backend to match the key.