Struct PrivateTubeData
pub struct PrivateTubeData {
pub public_inputs: PrivateToRollupKernelCircuitPublicInputs,
pub proof: TubeProof,
pub vk_data: VkData<115>,
}
Fields
public_inputs: PrivateToRollupKernelCircuitPublicInputsproof: TubeProofvk_data: VkData<115>Implementations
impl PrivateTubeData
pub fn validate_vk_in_vk_tree(self)
Trait implementations
impl Verifiable for PrivateTubeData
pub fn verify(self)
Verifies the proof against the verification key and public inputs. The vk hash is also checked in the backend to match the key.
Validates that the vk hash exists in the vk tree at the expected index.